@@ -41,7 +41,7 @@ has name => (
 See L<Net::ISC::DHCPd::Config::Role/regex>.
 
 =cut
-sub regex { qr{^\s* option \s+ space \s+ (.*) ;}x }
+our $regex = qr{^\s* option \s+ space \s+ (.*) ;}x;
 
 =head1 METHODS
 
